import React from 'react'
import { MinusCircleOutlined, PlusCircleOutlined, EditOutlined } from '@ant-design/icons';
import { Button, Form, Input, Space, Select, Modal, Collapse, Table} from 'antd';
import type { ColumnsType } from 'antd/es/table';
import ScriptEditor from './ScriptEditor';

const { Panel } = Collapse;

interface DataType {
  key: React.Key;
  name: string;
  field1: string;
  field2: string;
  field3: string;
  field4: string;
  field5: string;
  field6: string;
  field7: string;
  field8: string;
  field9: string;
}

const columns: ColumnsType<DataType> = [
  {
    title: 'Name',
    width: 100,
    dataIndex: 'name',
    key: 'name',
    fixed: 'left',
  },
  {
    title: 'String',
    children: [
      {
        title: 'field1',
        dataIndex: 'field1',
        key: '1',
         width: 150,
      },
      {
        title: 'field2',
        dataIndex: 'field2',
        key: '2',
         width: 150,
      },
      {
        title: 'field3',
        dataIndex: 'field3',
        key: '3',
         width: 150,
      },
    ]
  },
  {
    title: 'Int',
    children: [
      {
        title: 'field4',
        dataIndex: 'field4',
        key: '4',
         width: 150,
      },
      {
        title: 'field5',
        dataIndex: 'field5',
        key: '5',
         width: 150,
      },
      {
        title: 'field6',
        dataIndex: 'field6',
        key: '6',
         width: 150,
      },
    ]
  },
  {
    title: 'Text',
    children: [
      {
        title: 'field7',
        dataIndex: 'field7',
        key: '7',
         width: 150,
      },
      {
        title: 'field8',
        dataIndex: 'field8',
        key: '8',
         width: 150,
      },
      {
        title: 'field9',
        dataIndex: 'field9',
        key: '9',
         width: 150,
      },
    ]
  },
];

const data: DataType[] = [];
for (let i = 0; i < 100; i++) {
  data.push({
    key: i,
    name: `data ${i}`,
    field1: 'field1',
    field2: 'field2',
    field3: 'field3',
    field4: 'field4',
    field5: 'field5',
    field6: 'field6',
    field7: 'field7',
    field8: 'field8',
    field9: 'field9',
  });
}

export default class ScriptNodeInfo extends React.Component<any, any> {

  constructor(props: any) {
    super(props)
    this.state = {
      scriptModalVisible: false,
      scriptText: ''
    }
  }

  showScriptModal = () => {
    this.setState({scriptModalVisible: true})
  }

  submitScriptEdit = () => {
    this.props.nodeInfo.scriptText = this.state.scriptText
    this.setState({scriptModalVisible: false})
  }

  render() {
    return (
      <div className='node-script'>
        {/* 脚本节点信息 */}
        <Form
          name="datasourceInfo"
          autoComplete="off"
          layout='vertical'
          initialValues={{
            nodeId: this.props.nodeInfo.id,
            paramText: this.props.nodeInfo.paramText,
            outputData: this.props.nodeInfo.outputData
          }}
          onValuesChange={(changedValue, values) => {
            this.props.nodeInfo.paramText = values.paramText
            this.props.nodeInfo.outputData = values.outputData?.filter((item: any) => {
              return item && item.outputVar
            })
          }}
        >
          <Form.Item name='nodeId' label="节点ID">
            <Input disabled/>
          </Form.Item>
          <p>输入:</p>
          { 
            Array.from({ length: this.props.nodeInfo.inputNumber }, (_, i) => (
              <div style={{display: 'flex', alignItems: 'center', marginBottom: '8px', columnGap: '2px'}} key={i}>
                <Input disabled style={{flex: 1}} defaultValue={`t`+ i}/>
                <span style={{flex: 5}}>TABLE</span>
              </div>
            )) 
          }
          <Form.Item name='paramText' label="参数文本:">
            <Input.TextArea placeholder='# input will be transfered into context_string'/>
          </Form.Item>
          <Form.Item label="脚本编辑:">
            <Button type="link"
              onClick={this.showScriptModal}
              icon={<EditOutlined />}
              style={{paddingLeft: 0, paddingRight: 0}}
            >
              编辑脚本
            </Button>
          </Form.Item>
          <p>输出结果:</p>
          <Form.List name="outputData">
            {(fields, { add, remove }) => (
              <>
                {fields.map(({ key, name, ...restField }) => (
                  <Space key={key} style={{ display: 'flex', padding: '10px 10px 0', background: '#EDF0F6', marginBottom: '2px' }} align="baseline">
                    <Form.Item
                      label={'输出结果' + (key + 1)}
                      {...restField}
                      name={[name, 'outputVar']}
                    >
                      <Select options={[
                        {label: 'r1', value: 'r1'},
                        {label: 'r2', value: 'r2'},
                        {label: 'r3', value: 'r3'},
                        {label: 'r4', value: 'r4'},
                      ]} placeholder='请选择输出变量'/>
                    </Form.Item>
                    <MinusCircleOutlined onClick={() => remove(name)} style={{color:'#147BD1'}}/>
                  </Space>
                ))}
                <Form.Item>
                  <Button type="link" onClick={() => add()} icon={<PlusCircleOutlined />} style={{paddingLeft: 0, paddingRight: 0}}>
                    添加输出源
                  </Button>
                </Form.Item>
              </>
            )}
          </Form.List>
        </Form>
        {/* 脚本编辑弹窗 */}
        <Modal
          title="编辑脚本"
          open={this.state.scriptModalVisible}
          onOk={this.submitScriptEdit}
          className='script-modal'
          width={'90%'}
          style={{ top: 20 }}
          onCancel={() => {this.setState({scriptModalVisible: false})}}
          footer={[
            <Button key="back" onClick={() => {this.setState({scriptModalVisible: false})}}>取消</Button>,
            <Button key="check" type='primary' onClick={() => {console.log('代码校验');}}>代码校验</Button>,
            <Button key="submit" type='primary' onClick={this.submitScriptEdit}>确定修改</Button>
          ]}
        >
          <div className='modal-container'>
            {/* 数据表展示 */}
            <div className='modal-table'>
              <Collapse accordion>
                <Panel header="t1" key="1" style={{position: 'relative', paddingTop: 0}}>
                  <div style={{position: 'absolute', right: 0, left: 0}}>
                    <Table bordered columns={columns} dataSource={data} scroll={{ x: 1500, y: 400 }} />
                  </div>
                </Panel>
                <Panel header="t2" key="2"></Panel>
                <Panel header="t3" key="3"></Panel>
              </Collapse>
            </div>
            {/* 脚本编辑 */}
            <div className='modal-script'>
              <div className='script-header'></div>
              <ScriptEditor />
              {/* <CodeMirror
                style={{flex: 1}}
                height='100%'
                value={this.props.nodeInfo.scriptText}
                extensions={[sql()]}
                onChange={(val) => {
                  this.setState({scriptText: val})
                }}/> */}
            </div>
          </div>
        </Modal>
        
      </div>
    )
  }
}